Package: cfTools
Type: Package
Title: Informatics Tools for Cell-Free DNA Study
Version: 1.13.0
Authors@R: c(
    person(given = "Ran",
        family = "Hu",
        role = c("aut", "cre"),
        email = "huran@ucla.edu",
        comment = c(ORCID = "0000-0002-0563-8957")),
    person(c("Mary", "Louisa"), "Stackpole", 
        role = "aut",
        comment = c(ORCID = "0000-0003-4432-6718")),
    person("Shuo", "Li", 
        role = "aut",
        comment = c(ORCID = "0000-0002-1960-6016")),
    person(c("Xianghong", "Jasmine"), "Zhou", 
        role = "aut", 
        email = "XJZhou@mednet.ucla.edu", 
        comment = c(ORCID = "0000-0002-4522-7490")),
    person("Wenyuan", "Li", 
        role = "aut",
        email = "WenyuanLi@mednet.ucla.edu",
        comment = c(ORCID = "0000-0002-5029-8525")))
Description: The cfTools R package provides methods for cell-free DNA (cfDNA) 
    methylation data analysis to facilitate cfDNA-based studies. Given the 
    methylation sequencing data of a cfDNA sample, for each cancer marker 
    or tissue marker, we deconvolve the tumor-derived or tissue-specific reads 
    from all reads falling in the marker region. Our read-based deconvolution 
    algorithm exploits the pervasiveness of DNA methylation for signal enhancement, 
    therefore can sensitively identify a trace amount of tumor-specific or 
    tissue-specific cfDNA in plasma. cfTools provides functions for 
    (1) cancer detection: sensitively detect tumor-derived cfDNA and estimate 
    the tumor-derived cfDNA fraction (tumor burden); (2) tissue deconvolution: 
    infer the tissue type composition and the cfDNA fraction of multiple tissue 
    types for a plasma cfDNA sample. These functions can serve as foundations 
    for more advanced cfDNA-based studies, including cancer diagnosis and 
    disease monitoring.
License: file LICENSE
Encoding: UTF-8
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
RoxygenNote: 7.2.3
Imports: Rcpp, utils, GenomicRanges, basilisk, R.utils, stats,
        cfToolsData, grDevices, graphics
StagedInstall: no
biocViews: Software, BiomedicalInformatics, Epigenetics, Sequencing,
        MethylSeq, DNAMethylation, DifferentialMethylation
VignetteBuilder: knitr
LinkingTo: Rcpp, BH
URL: https://github.com/jasminezhoulab/cfTools
BugReports: https://github.com/jasminezhoulab/cfTools/issues
Config/Bioconductor/UnsupportedPlatforms: windows-x86
git_url: https://git.bioconductor.org/packages/cfTools
git_branch: devel
git_last_commit: 0441752
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-29
NeedsCompilation: yes
Packaged: 2026-04-29 20:54:07 UTC; biocbuild
Author: Ran Hu [aut, cre] (ORCID: <https://orcid.org/0000-0002-0563-8957>),
  Mary Louisa Stackpole [aut] (ORCID:
    <https://orcid.org/0000-0003-4432-6718>),
  Shuo Li [aut] (ORCID: <https://orcid.org/0000-0002-1960-6016>),
  Xianghong Jasmine Zhou [aut] (ORCID:
    <https://orcid.org/0000-0002-4522-7490>),
  Wenyuan Li [aut] (ORCID: <https://orcid.org/0000-0002-5029-8525>)
Maintainer: Ran Hu <huran@ucla.edu>
