my_env <- BasiliskEnvironment(envname="new_env",
                              pkgname="cfTools",
                              packages=c("python==3.8",
                                         "numpy==1.23.4", 
                                         "scipy==1.8.0",
                                         "tensorflow==2.10.0")
                              )
