#' Genomic postions of markers
#'
#' A BED file of genomic regions of markers
#'
#' @name markers.bed
#' 
#' @return A tibble with 3 rows and 4 variables
#' 
#' @format A tibble with 3 rows and 4 variables
#' \describe{
#' \item{chr}{Chromosome}
#' \item{start}{Chromosome start}
#' \item{end}{Chromosome end}
#' \item{markerName}{Marker name}
#' }
#' @usage data("markers.bed")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL
