#' Marker name
#'
#' A vector of marker names corresponding to the columns 
#' of the list of methylation levels.
#'
#' @name marker_index
#' 
#' @return A tibble with 3 rows and 1 variables
#' 
#' @format A tibble with 3 rows and 1 variables
#' \describe{
#' \item{markerIndex}{Marker name}
#' }
#' @usage data("marker_index")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL
