#' Sample type
#'
#' A vector of sample types (e.g., tumor or normal, 
#' tissue types) corresponding to the rows of the 
#' list of methylation levels.
#'
#' @name sample_type
#' 
#' @return A tibble with 20 rows and 1 variables
#' 
#' @format A tibble with 20 rows and 1 variables
#' \describe{
#' \item{sampleType}{Sample type}
#' }
#' @usage data("sample_type")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL
