#' Beta value matrix
#'
#' A list of methylation levels (e.g., beta values), 
#' where each row is a sample and each column is a marker
#'
#' @name beta_matrix
#' 
#' @return A tibble with 20 rows and 3 variables
#' 
#' @format A tibble with 20 rows and 3 variables
#' \describe{
#' \item{marker1}{Beta values of marker1 for all samples}
#' \item{marker2}{Beta values of marker2 for all samples}
#' \item{marker3}{Beta values of marker3 for all samples}
#' }
#' @usage data("beta_matrix")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL
