#' @useDynLib cfTools, .registration = TRUE
NULL
#' @importFrom Rcpp sourceCpp
NULL
#' @importFrom Rcpp evalCpp
NULL
#' @import Rcpp
NULL
#' @importFrom utils read.csv write.table read.delim
NULL
#' @import GenomicRanges
NULL
#' @importFrom basilisk basiliskRun BasiliskEnvironment
NULL
#' @importFrom basilisk basiliskStart basiliskStop
NULL
#' @importFrom R.utils gunzip
NULL
#' @importFrom utils read.table
NULL
#' @importFrom stats var setNames
NULL
#' @importFrom cfToolsData DNN1 DNN2
NULL
#' @importFrom graphics layout legend par pie plot.new
NULL
#' @importFrom grDevices rainbow
NULL