# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

read_deconvolution_cpp <- function(reads_binning_file, num_tissues, min_likelihood_ratio_cutoff, tissue_markers_file, em_algorithm_type, output_file, output_type, em_max_iterations = 100L, random_seed = 0L) {
    invisible(.Call(`_cfTools_read_deconvolution_cpp`, reads_binning_file, num_tissues, min_likelihood_ratio_cutoff, tissue_markers_file, em_algorithm_type, output_file, output_type, em_max_iterations, random_seed))
}

