#' Paired-end sequencing reads
#'
#' Paired-end sequencing reads information
#'
#' @name demo.sorted.bed
#' 
#' @return A tibble with 1117 rows and 6 variables
#' 
#' @format A tibble with 1117 rows and 6 variables
#' \describe{
#' \item{chr}{Chromosome name}
#' \item{start}{Chromosome start}
#' \item{end}{Chromosome end}
#' \item{name}{Sequence ID}
#' \item{score}{Mapping quality score}
#' \item{strand}{Strand}
#' }
#' @usage data("demo.sorted.bed")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL