#' Fragment-level information
#'
#' A BED file of fragment-level information
#'
#' @name demo.refo_frag.bed
#' 
#' @return A tibble with 559 rows and 6 variables
#' 
#' @format A tibble with 559 rows and 6 variables
#' \describe{
#' \item{chr}{Chromosome}
#' \item{start}{Chromosome start}
#' \item{end}{Chromosome end}
#' \item{fragmentLength}{Fragment length}
#' \item{strand}{Strand}
#' \item{name}{ID of the sequence}
#' }
#' @usage data("demo.refo_frag.bed")
#' 
#' @author Ran Hu \email{huran@ucla.edu}
NULL
